Learn R Programming

glmSTARMA (version 1.0.0)

summary.dglmstarma: Summarize a dglmstarma Model

Description

This functions summarizes the model fit of a dglmstarma model.

Usage

# S3 method for dglmstarma
summary(object, phi = 1, alternative = c("two.sided", "less", "greater"), ...)

Value

An object of class summary.dglmstarma which contains the following elements

  • call: The function call to fit the model

  • coefficients_mean: The estimated coefficients of the mean model with approximate standard errors, z- and p-values. See details.

  • coefficients_dispersion: The estimated coefficients of the dispersion model with approximate standard errors, z- and p-values. See details.

  • distribution: The marginal distribution of the conditional observations.

  • link: The link-function used to connect the conditional mean with the linear process of the mean model.

  • dispersion_link: The link-function used to connect the dispersion with the linear process of the dispersion model.

  • dispersion_disp_parameter: The dispersion parameter of the dispersion family

  • df_mean: Number of estimated coefficients in the mean model

  • df_dispersion: Number of estimated coefficients in the dispersion model

  • log_likelihood: The quasi-log-likelihood of the estimated model. See details.

  • aic: Akaike Information Criterion of the estimated model, see information_criteria with adjust = TRUE.

  • bic: Bayesian Information Criterion of the estimated model, see information_criteria with adjust = TRUE.

  • qic: Quasi Information Criterion of the estimated model, see QIC with adjust = TRUE.

Arguments

object

An object of class dglmstarma

phi

Numeric value indicating the null hypothesis value for the dispersion parameter test. Default is 1.

alternative

Character string specifying the alternative hypothesis for the dispersion parameter test. Must be one of "two.sided" (default), "less" or "greater".

...

Additional arguments passed to specific methods.

Details

Standard errors, z-values and p-values are computed assuming asymptotic normality of the parameter estimation. The variance estimation is based on the sandwich estimator to adjust for quasi-maximum-likelihood estimation. If the model requires non-negative parameters, the p-values are adjusted accordingly. Note that this adjustment is only valid for testing single parameters against the null hypothesis of being zero. If multiple parameters are tested simultaneously, or a linear combination of them, a different adjustment is necessary.

If the dispersion model is constant, i.e. it is only an intercept model, a test is performed to test whether the estimated dispersion parameter is significantly different from the null hypothesis value phi. The alternative hypothesis can be specified via the alternative argument. This can be useful to test for overdispersion or underdispersion in the data.

See Also

dglmstarma, summary.glmstarma

Examples

Run this code
# \donttest{
dat <- load_data("chickenpox", directory = tempdir())
chickenpox <- dat$chickenpox
population_hungary <- dat$population_hungary
W_hungary <- dat$W_hungary
mean_model <- list(past_obs = rep(1, 7))
dispersion_model <- list(past_obs = 1)
fit <- dglmstarma(chickenpox, mean_model, dispersion_model, mean_family = vquasipoisson("log"), 
                   dispersion_link = "log", wlist = W_hungary, 
                   mean_covariates = list(population = population_hungary))
summary(fit)
# }

Run the code above in your browser using DataLab