Learn R Programming

glmSTARMA (version 1.0.0)

summary.glmstarma: Summarize the results of a glmstarma model

Description

This functions summarizes the model fit of a glmstarma model

Usage

# S3 method for glmstarma
summary(object, ...)

Value

An object of class summary.glmstarma which contains the following elements

  • call: The function call to fit the model

  • coefficients: The estimated coefficients of the model with approximate standard errors, z- and p-values. See details.

  • distribution: The marginal distribution of the conditional observations.

  • link: The link-function used to connect the conditional mean with the linear process.

  • dispersion: The dispersion parameter of the conditional distribution

  • estimate_dispersion: logical value indicating whether dispersion was estimated (TRUE) or fixed by the distribution or user (FALSE)

  • df: Number of estimated coefficients in the model

  • log_likelihood: The quasi-log-likelihood of the estimated model. See details.

  • aic: Akaike Information Criterion of the estimated model, see information_criteria with adjust = TRUE.

  • bic: Bayesian Information Criterion of the estimated model, see information_criteria with adjust = TRUE.

  • qic: Quasi Information Criterion of the estimated model, see QIC with adjust = TRUE.

Arguments

object

An object of class glmstarma

...

Additional arguments passed to specific methods.

Details

Standard errors, z-values and p-values are computed assuming asymptotic normality of the parameter estimation. The variance estimation is based on the sandwich estimator to adjust for quasi-maximum-likelihood estimation.

If the model requires non-negative parameters, the p-values are adjusted accordingly. Note that this adjustment is only valid for testing single parameters against the null hypothesis of being zero. If multiple parameters are tested simultaneously, or a linear combination of them, a different adjustment is necessary.

See Also

glmstarma, logLik, AIC, BIC, QIC, logLik.glmstarma, AIC.glmstarma, BIC.glmstarma

Examples

Run this code
# \donttest{
dat <- load_data("chickenpox", directory = tempdir())
chickenpox <- dat$chickenpox
population_hungary <- dat$population_hungary
W_hungary <- dat$W_hungary

model_autoregressive <- list(past_obs = rep(1, 7))
fit <- glmstarma(chickenpox, model_autoregressive, W_hungary, family = vpoisson("log"),
                 covariates = list(population = population_hungary))
summary(fit)
# }

Run the code above in your browser using DataLab