call: The function call to fit the model
coefficients_mean: The estimated coefficients of the mean model with approximate standard errors, z- and p-values. See details.
coefficients_dispersion: The estimated coefficients of the dispersion model with approximate standard errors, z- and p-values. See details.
distribution: The marginal distribution of the conditional observations.
link: The link-function used to connect the conditional mean with the linear process of the mean model.
dispersion_link: The link-function used to connect the dispersion with the linear process of the dispersion model.
dispersion_disp_parameter: The dispersion parameter of the dispersion family
df_mean: Number of estimated coefficients in the mean model
df_dispersion: Number of estimated coefficients in the dispersion model
log_likelihood: The quasi-log-likelihood of the estimated model. See details.
aic: Akaike Information Criterion of the estimated model, see information_criteria with adjust = TRUE.
bic: Bayesian Information Criterion of the estimated model, see information_criteria with adjust = TRUE.
qic: Quasi Information Criterion of the estimated model, see QIC with adjust = TRUE.